/* This file is in the public domain. */
html{ text-align: center; }

body, rss {
    font-family: "DejaVu Serif", serif;
    font-style: normal;
    font-size: 16pt;
    padding: 1em 3em;
    width: 72ex;
    display: inline-block;
    text-align: left;
    color: #000;
    background-color: #fff;
}

textarea {
    width: 100%;
    font-family: "DejaVu Mono", courrier, monospace;
    font-size: inherit;
    margin: 0;
    padding: 0;
}

input, button {
    font-family: inherit;
    font-size: 90%;
}

pre {
    white-space: pre-wrap;
    word-break: break-all;
}

/* FIXME: These rules are only necessary because of the markup
   generated by the Markdown parser. */
li p { margin: 0 }

/* Menu at the top */

#header ul { display: block; padding: 0; }
#header li { display: inline }

/* Diff */

.insert, .delete { white-space: pre-wrap; padding: 2pt; }
.insert { background: #c1ffc1; }
.insert ins { background: #b4eeb4; }
.delete { background: #ff82ab; }
.delete del { background: #ee799f; }

/* Changes */

li { padding-bottom: 5pt; }

.c1 { background: red; color: red; }
.c2 { background: orange; color: orange; }
.c3 { background: yellow; color: yellow; }
.c4 { background: green; color: green; }
.c5 { background: blue; color: blue; }
.c6 { background: indigo; color: indigo; }
.c7 { background: violet; color: violet; }
.c8 { background: white; color: white; }
.ip-code { border: 1px solid #666; }

/* Filter */

#filter label.wide { display:inline-block; width: 20ex; border: none;}
#filter input.wide {
    display:inline-block;
    width: 20ex;
    border-top-style: hidden;
    border-right-style: hidden;
    border-left-style: hidden;
    font-weight: bold;
}
#filter input.narrow { display:inline-block; width: 5ex; }

/* Warning Message */

.message { font-weight: bold; }

/* Titles and Whitespace */

h1, h2, h3, title {
    font-family: inherit;
    font-weight: normal;
}
h1 {
    font-size: 200%;
    margin: 16pt 0 8pt 0;
    padding: 4pt 0;
}
h2 {
    font-size: 150%;
    margin: 32pt 0 0 0;
    padding: 0;
}
h3 {
    font-size: inherit;
    font-weight: bold;
    padding: 0;
    margin: 16pt 0 0 0;
    clear: both;
}

/* Links in headings. */

h1 a, h2 a, h3 a {
    color:inherit;
    text-decoration:none;
    font-weight: normal;
} 
h1 a:visited, h2 a:visited, h3 a:visited {
    color: inherit;
}

/* Images */

img { max-width: 100% }

/* Tables */

th, td { padding: 0 8pt 8pt 0; }
.half { width: 50%; }
tr { vertical-align: top; }

/* Edit Page */

#text { height: 20em }
#summary { height: 3em }
#summarylabel { margin-bottom: 0 }

/* handheld devices get less whitespace */

@media only screen and (max-device-width: 600px) {
    body {
	font-size: 40pt;
	max-width: 100%;
	padding: 0;
    }
    body > div { padding: 10pt 20pt; }
    .header input { max-width: 7ex; }
    .new input { max-width: 23ex; }
    .footer { font-size: 80%; }
}
